@@ -84,7 +84,8 @@ class ApiClient:
     def get_project_by_name(self, project_name: str) -> Dict:
         projs = self.make_request(
             RequestType.GET,
-            url=f"{config.api_url}/{Route.projects}?project_name={project_name}",
+            url=f"{config.api_url}/{Route.projects}",
+            params={"project_name": project_name},
         )
         return projs[0] if projs else {}
 
@@ -114,11 +115,9 @@ class ApiClient:
         proj = self.get_project_by_name(project_name)
         if not proj:
             raise GalileoException(f"No project with name {project_name}")
-        url = (
-            f"{config.api_url}/{Route.projects}/{proj['id']}/{Route.runs}?"
-            f"run_name={run_name}"
-        )
-        runs = self.make_request(RequestType.GET, url=url)
+        url = f"{config.api_url}/{Route.projects}/{proj['id']}/{Route.runs}"
+        params = {"run_name": run_name}
+        runs = self.make_request(RequestType.GET, url=url, params=params)
         return runs[0] if runs else {}
 
     def create_project(self, project_name: str, is_public: bool = True) -> Dict:
@@ -138,7 +137,9 @@ class ApiClient:
             body=body,
         )
 
-    def reset_run(self, project_id: UUID4, run_id: UUID4) -> None:
+    def reset_run(
+        self, project_id: UUID4, run_id: UUID4, task_type: Optional[TaskType] = None
+    ) -> None:
         """Resets a run by deleting the run with that name and creating a new one
         with the same name, getting a new UUID
 
@@ -148,14 +149,12 @@ class ApiClient:
         project_name = self.get_project(project_id)["name"]
         run = self.get_project_run(project_id, run_id)
         run_name = run["name"]
-        task_type = run["task_type"]
+        task_type = task_type or TaskType.get_mapping(run["task_type"])
 
         # Delete the run
         self.delete_run(project_id, run_id)
         # Create a run with the same name
-        new_run = self.create_run(
-            project_name, run_name, TaskType.get_mapping(task_type)
-        )
+        new_run = self.create_run(project_name, run_name, task_type)
         # Update config
         config.current_run_id = new_run["id"]
 
@@ -177,7 +176,7 @@ class ApiClient:
         run = self.get_project_run_by_name(project_name, run_name)
         if not run:
             raise GalileoException(
-                f"No project/run found with name " f"{project_name}/{run_name}"
+                f"No project/run found with name {project_name}/{run_name}"
             )
         project_id = run["project_id"]
         run_id = run["id"]
@@ -258,9 +257,8 @@ class ApiClient:
         )
 
         url = f"{config.api_url}/{Route.content_path(project, run)}/{Route.labels}"
-        if task:
-            url += f"?task={task}"
-        res = self.make_request(RequestType.GET, url=url)
+        params = {"task": task} if task else None
+        res = self.make_request(RequestType.GET, url=url, params=params)
         return res["labels"]
 
     def get_tasks_for_run(
@@ -276,6 +274,8 @@ class ApiClient:
         project, run = self._get_project_run_id(
             project_name=project_name, run_name=run_name
         )
+        if self.get_task_type(project, run) != TaskType.text_multi_label:
+            return []
         url = f"{config.api_url}/{Route.content_path(project, run)}/{Route.tasks}"
         res = self.make_request(RequestType.GET, url=url)
         return res["tasks"]
@@ -362,11 +362,9 @@ class ApiClient:
     def get_slice_by_name(self, project_name: str, slice_name: str) -> Dict:
         """Get a slice by name"""
         proj = self.get_project_by_name(project_name)
-        url = (
-            f"{config.api_url}/{Route.content_path(proj['id'])}/{Route.slices}?"
-            f"slice_name={slice_name}"
-        )
-        slices = self.make_request(RequestType.GET, url=url)
+        url = f"{config.api_url}/{Route.content_path(proj['id'])}/{Route.slices}"
+        params = {"slice_name": slice_name}
+        slices = self.make_request(RequestType.GET, url=url, params=params)
         if not slices:
             raise GalileoException(
                 f"No slice found for project {project_name} with name {slice_name}"
@@ -442,12 +440,20 @@ class ApiClient:
             url, json=body, stream=True, headers=headers(config.token)
         ) as r:
             r.raise_for_status()
+            # If a run/split or a set of filters has no data, the API will return a 200
+            # with a special header letting us know, so we don't try to load a file
+            # with an unexpected format
+            if r.headers.get("Galileo-No-Data") == "true":
+                raise GalileoException(
+                    f"It seems there is no data for run {project_name}/{run_name}/"
+                    f"{split}.\nEnsure you spelled everything correctly. "
+                    "Projects and runs are case sensitive."
+                )
+
             with open(file_name, "wb") as f:
                 for chunk in r.iter_content(chunk_size=8192):
                     f.write(chunk)
 
-        print(f"Your export has been written to {file_name}")
-
     def get_project_run_name(
         self, project_id: Optional[UUID4] = None, run_id: Optional[UUID4] = None
     ) -> Tuple[str, str]:
@@ -577,8 +583,49 @@ class ApiClient:
             )
 
         path = Route.content_path(project, run, split)
-        url = f"{config.api_url}/{path}/{Route.groupby}?groupby_col={category}"
+        url = f"{config.api_url}/{path}/{Route.groupby}"
+        params = {"groupby_col": category}
         if inference_name:
-            url += f"?inference_name={inference_name}"
+            params["inference_name"] = inference_name
         body = {"task": task, "filter_params": filter_params or {}}
-        return self.make_request(RequestType.POST, url, body=body)
+        return self.make_request(RequestType.POST, url, body=body, params=params)
+
+    def get_column_distribution(
+        self,
+        project_name: str,
+        run_name: str,
+        split: str,
+        task: str = None,
+        inference_name: str = None,
+        column: str = "data_error_potential",
+        filter_params: Dict = None,
+    ) -> Dict[str, List]:
+        project, run = self._get_project_run_id(project_name, run_name)
+        split = conform_split(split)
+
+        all_meta = self.get_metadata_columns(project_name, run_name, split)
+        continuous_meta = [i["name"] for i in all_meta["meta"] if i["is_continuous"]]
+        avl_cols = continuous_meta + ["data_error_potential"]
+        if column not in avl_cols:
+            raise GalileoException(
+                f"Column must be one of continuous columns {avl_cols} for this run "
+                f"but got {column}"
+            )
+
+        path = Route.content_path(project, run, split)
+        url = f"{config.api_url}/{path}/{Route.distribution}"
+        params = {"col": column}
+        if inference_name:
+            params["inference_name"] = inference_name
+        body = {"task": task, "filter_params": filter_params or {}}
+        return self.make_request(RequestType.POST, url, body=body, params=params)
+
+    def get_xray_cards(
+        self, project_name: str, run_name: str, split: str, inference_name: str = None
+    ) -> List[Dict[str, str]]:
+        """Queries API for xray cards for a run/split"""
+        project, run = self._get_project_run_id(project_name, run_name)
+        path = Route.content_path(project, run, split)
+        url = f"{config.api_url}/{path}/{Route.xray}"
+        params = {"inference_name": inference_name} if inference_name else None
+        return self.make_request(RequestType.GET, url, params=params)
