@@ -27,6 +27,8 @@ class Route(str, Enum):
     epochs = "epochs"
     summary = "insights/summary"
     groupby = "insights/groupby"
+    distribution = "insights/distribution"
+    xray = "insights/xray"
 
     @staticmethod
     def content_path(
