@@ -6,6 +6,7 @@ from uuid import uuid4
 
 import pytest
 
+import dataquality.clients.api
 from dataquality import config
 from dataquality.clients.api import ApiClient
 from dataquality.exceptions import GalileoException
@@ -14,11 +15,11 @@ from tests.utils.mock_request import (
     EXISTING_PROJECT,
     EXISTING_RUN,
     FAKE_NEW_RUN,
+    MockResponse,
     mocked_delete_project_not_found,
     mocked_delete_project_run,
     mocked_get_project_run,
     mocked_missing_project_name,
-    mocked_missing_run,
 )
 
 api_client = ApiClient()
@@ -99,14 +100,20 @@ def test_delete_run_by_name(
     api_client.delete_run_by_name(EXISTING_PROJECT, EXISTING_RUN)
 
 
-@mock.patch("requests.get", side_effect=mocked_missing_run)
+@mock.patch("requests.get")
 def test_delete_run_by_name_missing_run(
     mock_get_run: MagicMock, set_test_config: Callable
 ) -> None:
-    """Base case: Tests creating a new project and run"""
-    with pytest.raises(GalileoException):
+    """tests deleting a project/run with a run name that doesn't exist"""
+    mock_get_run.side_effect = [
+        MockResponse(json_data=[{"id": "uuid"}], status_code=200),
+        MockResponse(json_data=[], status_code=200),
+    ]
+    with pytest.raises(GalileoException) as e:
         api_client.delete_run_by_name("some_proj", "some_run")
 
+    assert str(e.value) == "No project/run found with name some_proj/some_run"
+
 
 @pytest.mark.parametrize(
     "api_url",
@@ -276,3 +283,23 @@ def test_get_run_status_no_status(
     """Asserts that wait_for_run with an empty status doens't crash"""
     api_client.wait_for_run()
     assert mock_get_status.call_count == 2
+
+
+@patch.object(dataquality.clients.api.requests, "post")
+@patch.object(dataquality.clients.api.ApiClient, "get_task_type")
+@patch.object(dataquality.clients.api.ApiClient, "_get_project_run_id")
+def test_export_run_no_data(
+    mock_get_run: MagicMock, mock_get_task_type: MagicMock, mock_post: MagicMock
+) -> None:
+    mock_get_run.return_value = uuid4(), uuid4()
+    mock_get_task_type.return_value = TaskType.text_classification
+    # In export_run we use requests.post as a context manager (with requests.post(...))
+    # so we need to mock the `__enter__` return value
+    mock_post.return_value.__enter__.return_value = MockResponse(
+        status_code=200, json_data={}, headers={"Galileo-No-Data": "true"}
+    )
+    with pytest.raises(GalileoException) as e:
+        api_client.export_run("project", "run", "training", "file.csv")
+    assert str(e.value).startswith(
+        "It seems there is no data for run project/run/training"
+    )
